Use ndnpeek and ndnpoke

refs #2858

Change-Id: Idefbe54ac6c5cc0fc9e4a6197f882c027b551a8b
diff --git a/test_localhost_scope/README.md b/test_localhost_scope/README.md
index deda7a6..52d95be 100644
--- a/test_localhost_scope/README.md
+++ b/test_localhost_scope/README.md
@@ -6,27 +6,27 @@
 
 1. On host B, start NFD.
 2. On host B, start ndn-traffic-server to serve `ndn:/localhost/test-in`.
-3. On host A, start [socat](http://linux.die.net/man/1/socat) to create a relay from a listening UNIX socket to TCP hostB:6363.  
+3. On host A, start [socat](http://linux.die.net/man/1/socat) to create a relay from a listening UNIX socket to TCP hostB:6363.
    Write the path of this UNIX socket to `$HOME/.ndn/client.conf`.
-4. On host A, invoke ndn-tlv-peek to request `ndn:/localhost/test-in/A`.  
+4. On host A, invoke ndnpeek to request `ndn:/localhost/test-in/A`.
    Fail if Interest is answered.
-5. On host B, stop ndn-traffic-server.  
+5. On host B, stop ndn-traffic-server.
    Fail if total served Interest does not equal 0.
 6. On host A, kill socat and restore `$HOME/.ndn/client.conf`.
 
 ## Outgoing scope control
 
-1. On host A, start [netcat](http://linux.die.net/man/1/nc) to listen on TCP port 6363.  
+1. On host A, start [netcat](http://linux.die.net/man/1/nc) to listen on TCP port 6363.
    Redirect netcat output into a file.
-2. On host B, invoke nfdc to create face tcp://hostA:6363.  
+2. On host B, invoke nfdc to create face tcp://hostA:6363.
    Fail if nfdc fails.
-3. On host B, invoke nfdc to add nexthop for `ndn:/` toward face created in step 8.  
+3. On host B, invoke nfdc to add nexthop for `ndn:/` toward face created in step 8.
    Fail if nfdc fails.
-4. On host B, invoke nfdc to add nexthop for `ndn:/localhost/test-out` toward face created in step 8.  
+4. On host B, invoke nfdc to add nexthop for `ndn:/localhost/test-out` toward face created in step 8.
    Do not fail if nfdc fails (forwarder MAY reject prefix registration that violates scope control).
-5. On host B, invoke ndn-tlv-peek to request `ndn:/localhost/test-out/B/c39b6fed4ce4464ea136062f80002c7c`.
-6. On host B, invoke ndn-tlv-peek to request `ndn:/localhost/C/c39b6fed4ce4464ea136062f80002c7c`.
-7. On host B, invoke ndn-tlv-peek to request `ndn:/ref-out/D/3b5fe3f184ff48adb3523180dee50555`.
-8. On host A, stop netcat.  
-   Search netcat output for string "c39b6fed4ce4464ea136062f80002c7c". Fail if this string exists.  
+5. On host B, invoke ndnpeek to request `ndn:/localhost/test-out/B/c39b6fed4ce4464ea136062f80002c7c`.
+6. On host B, invoke ndnpeek to request `ndn:/localhost/C/c39b6fed4ce4464ea136062f80002c7c`.
+7. On host B, invoke ndnpeek to request `ndn:/ref-out/D/3b5fe3f184ff48adb3523180dee50555`.
+8. On host A, stop netcat.
+   Search netcat output for string "c39b6fed4ce4464ea136062f80002c7c". Fail if this string exists.
    Search netcat output for string "3b5fe3f184ff48adb3523180dee50555". Fail if this string does not exist.
diff --git a/test_localhost_scope/in-master.sh b/test_localhost_scope/in-master.sh
index 756ffd7..c782aed 100755
--- a/test_localhost_scope/in-master.sh
+++ b/test_localhost_scope/in-master.sh
@@ -25,7 +25,7 @@
 sleep 1
 
 # send interest
-response=$(ndn-tlv-peek -p ndn:/localhost/test-in/A 2>&1)
+response=$(ndnpeek -p ndn:/localhost/test-in/A 2>&1)
 if [[ ! -z $response ]]
 then
     echo "FAIL: Expected no data come back for ndn:/localhost/test-in/A, Actual: '$response'"
diff --git a/test_localhost_scope/out-master.sh b/test_localhost_scope/out-master.sh
index f75cc78..742c688 100755
--- a/test_localhost_scope/out-master.sh
+++ b/test_localhost_scope/out-master.sh
@@ -27,10 +27,10 @@
     exit 4
 fi
 
-# On B, use ndn-tlv-peek to request names that starts with ndn:/localhost
-r=$(ssh $CTRL_B "ndn-tlv-peek -p ndn:/localhost/test-out/B/c39b6fed4ce4464ea136062f80002c7c;\
-                 ndn-tlv-peek -p ndn:/localhost/C/c39b6fed4ce4464ea136062f80002c7c;\
-                 ndn-tlv-peek -p ndn:/ref-out/D/3b5fe3f184ff48adb3523180dee50555")
+# On B, use ndnpeek to request names that starts with ndn:/localhost
+r=$(ssh $CTRL_B "ndnpeek -p ndn:/localhost/test-out/B/c39b6fed4ce4464ea136062f80002c7c;\
+                 ndnpeek -p ndn:/localhost/C/c39b6fed4ce4464ea136062f80002c7c;\
+                 ndnpeek -p ndn:/ref-out/D/3b5fe3f184ff48adb3523180dee50555")
 sleep 2
 
 # stop netcat and examine netcat.log